@@ -18,7 +18,7 @@ use crate::toolset::ToolRequest;
 
 #[derive(Debug)]
 pub struct CargoBackend {
-    fa: BackendArg,
+    ba: BackendArg,
     remote_version_cache: CacheManager<Vec<String>>,
 }
 
@@ -28,7 +28,7 @@ impl Backend for CargoBackend {
     }
 
     fn fa(&self) -> &BackendArg {
-        &self.fa
+        &self.ba
     }
 
     fn get_dependencies(&self, _tvr: &ToolRequest) -> eyre::Result<Vec<BackendArg>> {
@@ -102,13 +102,12 @@ impl Backend for CargoBackend {
 }
 
 impl CargoBackend {
-    pub fn new(name: String) -> Self {
-        let fa = BackendArg::new(BackendType::Cargo, &name);
+    pub fn from_arg(ba: BackendArg) -> Self {
         Self {
             remote_version_cache: CacheManager::new(
-                fa.cache_path.join("remote_versions-$KEY.msgpack.z"),
+                ba.cache_path.join("remote_versions-$KEY.msgpack.z"),
             ),
-            fa,
+            ba,
         }
     }
 
