@@ -12,7 +12,7 @@ use crate::toolset::ToolRequest;
 
 #[derive(Debug)]
 pub struct NPMBackend {
-    fa: BackendArg,
+    ba: BackendArg,
     remote_version_cache: CacheManager<Vec<String>>,
     latest_version_cache: CacheManager<Option<String>>,
 }
@@ -23,7 +23,7 @@ impl Backend for NPMBackend {
     }
 
     fn fa(&self) -> &BackendArg {
-        &self.fa
+        &self.ba
     }
 
     fn get_dependencies(&self, _tvr: &ToolRequest) -> eyre::Result<Vec<BackendArg>> {
@@ -77,16 +77,15 @@ impl Backend for NPMBackend {
 }
 
 impl NPMBackend {
-    pub fn new(name: String) -> Self {
-        let fa = BackendArg::new(BackendType::Npm, &name);
+    pub fn from_arg(ba: BackendArg) -> Self {
         Self {
             remote_version_cache: CacheManager::new(
-                fa.cache_path.join("remote_versions-$KEY.msgpack.z"),
+                ba.cache_path.join("remote_versions-$KEY.msgpack.z"),
             ),
             latest_version_cache: CacheManager::new(
-                fa.cache_path.join("latest_version-$KEY.msgpack.z"),
+                ba.cache_path.join("latest_version-$KEY.msgpack.z"),
             ),
-            fa,
+            ba,
         }
     }
 }
