@@ -1,6 +1,6 @@
 use color_eyre::eyre::{eyre, Result};
 
-use crate::cli::args::ForgeArg;
+use crate::cli::args::BackendArg;
 use crate::config::Config;
 
 /// Show an alias for a plugin
@@ -11,7 +11,7 @@ use crate::config::Config;
 #[clap(after_long_help = AFTER_LONG_HELP, verbatim_doc_comment)]
 pub struct AliasGet {
     /// The plugin to show the alias for
-    pub plugin: ForgeArg,
+    pub plugin: BackendArg,
     /// The alias to show
     pub alias: String,
 }
@@ -41,11 +41,13 @@ static AFTER_LONG_HELP: &str = color_print::cstr!(
 
 #[cfg(test)]
 mod tests {
-    use crate::test::reset_config;
+    use insta::assert_snapshot;
+
+    use crate::test::reset;
 
     #[test]
     fn test_alias_get() {
-        reset_config();
+        reset();
         let stdout = assert_cli!("alias", "get", "tiny", "my/alias");
         assert_snapshot!(stdout, @r###"
         3.0
@@ -54,12 +56,14 @@ mod tests {
 
     #[test]
     fn test_alias_get_plugin_unknown() {
+        reset();
         let err = assert_cli_err!("alias", "get", "unknown", "unknown");
         assert_snapshot!(err, @"Unknown plugin: unknown");
     }
 
     #[test]
     fn test_alias_get_alias_unknown() {
+        reset();
         let err = assert_cli_err!("alias", "get", "tiny", "unknown");
         assert_snapshot!(err, @"Unknown alias: unknown");
     }
