@@ -63,6 +63,7 @@ mod tests {
         all_compile = false
         always_keep_download = true
         always_keep_install = true
+        asdf = true
         asdf_compat = false
         cargo_binstall = true
         color = true
@@ -90,6 +91,7 @@ mod tests {
         raw = false
         trusted_config_paths = []
         verbose = true
+        vfox = false
         yes = true
 
         [status]
@@ -107,6 +109,7 @@ mod tests {
         all_compile
         always_keep_download
         always_keep_install
+        asdf
         asdf_compat
         cargo_binstall
         color
@@ -138,6 +141,7 @@ mod tests {
         status.show_tools
         trusted_config_paths
         verbose
+        vfox
         yes
         "###);
     }
