@@ -5,11 +5,10 @@ use eyre::Result;
 use once_cell::sync::Lazy;
 use versions::Versioning;
 
-use crate::build_time::{built_info, BUILD_TIME};
+use crate::build_time::{git_sha, BUILD_TIME};
 use crate::cli::self_update::SelfUpdate;
-use crate::env;
 use crate::file::modified_duration;
-use crate::{dirs, duration, file};
+use crate::{dirs, duration, env, file};
 
 #[derive(Debug, clap::Args)]
 #[clap(about = "Show mise version", alias = "v")]
@@ -31,7 +30,7 @@ pub static VERSION: Lazy<String> = Lazy::new(|| {
         v.push_str("-DEBUG");
     };
     let build_time = BUILD_TIME.format("%Y-%m-%d");
-    let extra = match &built_info::GIT_COMMIT_HASH_SHORT {
+    let extra = match git_sha() {
         Some(sha) => format!("({} {})", sha, build_time),
         _ => format!("({})", build_time),
     };
@@ -79,7 +78,7 @@ fn show_latest() {
 }
 
 pub fn check_for_new_version(cache_duration: Duration) -> Option<String> {
-    if let Some(latest) = get_latest_version(cache_duration).and_then(|v| Versioning::new(&v)) {
+    if let Some(latest) = get_latest_version(cache_duration).and_then(Versioning::new) {
         if *V < latest {
             return Some(latest.to_string());
         }
