@@ -5,7 +5,7 @@ use std::path::{Path, PathBuf};
 use eyre::Result;
 
 use crate::dirs::TRACKED_CONFIGS;
-use crate::file::{create_dir_all, make_symlink};
+use crate::file::{create_dir_all, make_symlink_or_file};
 use crate::hash::hash_to_str;
 
 pub struct Tracker {}
@@ -15,7 +15,7 @@ impl Tracker {
         let tracking_path = TRACKED_CONFIGS.join(hash_to_str(&path));
         if !tracking_path.exists() {
             create_dir_all(&*TRACKED_CONFIGS)?;
-            make_symlink(path, &tracking_path)?;
+            make_symlink_or_file(path, &tracking_path)?;
         }
         Ok(())
     }
